.. _explicit_methods_in_number_theory:

Three Lectures about Explicit Methods in Number Theory Using Sage
=================================================================

.. MODULEAUTHOR:: William Stein (2008)

This article is about using the mathematical software Sage to do
computations with number fields and modular forms.  It was written
for the October 2008 Bordeaux meeting on explicit methods in number
theory (http://www.math.u-bordeaux.fr/gtem2008/).  It assumes
no prior knowledge about Sage, but assumes a graduate level
background in algebraic number theory.

.. toctree::
   :maxdepth: 2

   introduction
   number_fields
   birds_eye_view
   modular_forms
